# Copyright © 2019-2023 HQS Quantum Simulations GmbH. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
# in compliance with the License. You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under the License
# is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
# or implied. See the License for the specific language governing permissions and limitations under
# the License.

"""QASM interface and backend for qoqo.

Translates qoqo operations and circuits to QASM operations via the interface,
and Create a Qasm file with QasmBackend.

.. autosummary::
    :toctree: generated/

    qasm_call_operation
    qasm_call_circuit
    QasmBackend

"""

from .qoqo_qasm import *
